# coding: utf-8

"""
    ORY Keto

    A cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: v0.0.0-alpha.1
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import ory_keto_client
from ory_keto_client.models.input import Input  # noqa: E501
from ory_keto_client.rest import ApiException


class TestInput(unittest.TestCase):
    """Input unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInput(self):
        """Test Input"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ory_keto_client.models.input.Input()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from ory_keto_client.api.engines_api import EnginesApi
from ory_keto_client.api.health_api import HealthApi
from ory_keto_client.api.version_api import VersionApi



# coding: utf-8

# flake8: noqa

"""
    ORY Keto

    Ory Keto is a cloud native access control server providing best-practice patterns (RBAC, ABAC, ACL, AWS IAM Policies, Kubernetes Roles, ...) via REST APIs.  # noqa: E501

    The version of the OpenAPI document: Latest
    Contact: hi@ory.sh
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "v0.4.0-alpha.1"

# import apis into sdk package
from ory_keto_client.api.engines_api import EnginesApi
from ory_keto_client.api.health_api import HealthApi
from ory_keto_client.api.version_api import VersionApi

# import ApiClient
from ory_keto_client.api_client import ApiClient
from ory_keto_client.configuration import Configuration
from ory_keto_client.exceptions import OpenApiException
from ory_keto_client.exceptions import ApiTypeError
from ory_keto_client.exceptions import ApiValueError
from ory_keto_client.exceptions import ApiKeyError
from ory_keto_client.exceptions import ApiException
# import models into sdk package
from ory_keto_client.models.add_ory_access_control_policy_role_members_body import AddOryAccessControlPolicyRoleMembersBody
from ory_keto_client.models.add_ory_access_control_policy_role_members_internal_server_error_body import AddOryAccessControlPolicyRoleMembersInternalServerErrorBody
from ory_keto_client.models.authorization_result import AuthorizationResult
from ory_keto_client.models.delete_ory_access_control_policy_internal_server_error_body import DeleteOryAccessControlPolicyInternalServerErrorBody
from ory_keto_client.models.delete_ory_access_control_policy_role_internal_server_error_body import DeleteOryAccessControlPolicyRoleInternalServerErrorBody
from ory_keto_client.models.do_ory_access_control_policies_allow_internal_server_error_body import DoOryAccessControlPoliciesAllowInternalServerErrorBody
from ory_keto_client.models.get_ory_access_control_policy_internal_server_error_body import GetOryAccessControlPolicyInternalServerErrorBody
from ory_keto_client.models.get_ory_access_control_policy_not_found_body import GetOryAccessControlPolicyNotFoundBody
from ory_keto_client.models.get_ory_access_control_policy_role_internal_server_error_body import GetOryAccessControlPolicyRoleInternalServerErrorBody
from ory_keto_client.models.get_ory_access_control_policy_role_not_found_body import GetOryAccessControlPolicyRoleNotFoundBody
from ory_keto_client.models.health_not_ready_status import HealthNotReadyStatus
from ory_keto_client.models.health_status import HealthStatus
from ory_keto_client.models.inline_response500 import InlineResponse500
from ory_keto_client.models.is_instance_alive_internal_server_error_body import IsInstanceAliveInternalServerErrorBody
from ory_keto_client.models.list_ory_access_control_policies_internal_server_error_body import ListOryAccessControlPoliciesInternalServerErrorBody
from ory_keto_client.models.list_ory_access_control_policy_roles_internal_server_error_body import ListOryAccessControlPolicyRolesInternalServerErrorBody
from ory_keto_client.models.ory_access_control_policy import OryAccessControlPolicy
from ory_keto_client.models.ory_access_control_policy_allowed_input import OryAccessControlPolicyAllowedInput
from ory_keto_client.models.ory_access_control_policy_role import OryAccessControlPolicyRole
from ory_keto_client.models.remove_ory_access_control_policy_role_members_internal_server_error_body import RemoveOryAccessControlPolicyRoleMembersInternalServerErrorBody
from ory_keto_client.models.upsert_ory_access_control_policy_internal_server_error_body import UpsertOryAccessControlPolicyInternalServerErrorBody
from ory_keto_client.models.upsert_ory_access_control_policy_role_internal_server_error_body import UpsertOryAccessControlPolicyRoleInternalServerErrorBody
from ory_keto_client.models.version import Version

